==> basic-data-api-1.0.51.tgz: package/src/RequestSettings/tachingClass.js <==
//教学班接口
import {
  submit,
  batchDeletion,
  pagingQuery,
  singleQueryPath,
  postQueryData,
} from "../publicMethod/PublicMethod.js";
import teachingClassApi from "../api/teachingClassApi";
import { request } from "../globalConfiguration";
//教学班接口
const PagesData = {
  teaclaName: undefined,
  teaclaNumber: undefined,
  lecturerId: undefined,
  lecturerName: undefined,
  courseName: undefined,
  courseId: undefined,
  startTime: undefined,
  overTime: undefined,
  time: undefined,
  teaclaId: undefined, //教学Id
  adminclaIds: undefined, // 行政班id列表
  studentsIds: undefined, //学生Id列表
  orgId: undefined, // 机构id
  orgName: undefined, //机构名称
  stuproId: undefined, //学生专业id
  stuproName: undefined, //学生专业名称
  stuName: undefined, //学生姓名
  stuNumber: undefined, //学号
};
/**
 *添加教学班
 * @param {data} 参数
 * {teaclaNumber} 教学班编号
 * {teaclaName} 教学班名称
 * {lecturerId}  授课老师id
 * {lecturerName} 授课老师名称
 * {courseId} 课程id
 * {courseName} 课程名称
 * {startTime} 开始时间
 * {overTime} 结束时间
 * @param {config} 配置项
 * @returns
 */
function teaCalAdd(data = PagesData, config = {}) {
  return request(
    submit(
      {
        jxbbh: data.teaclaNumber || undefined, //教学班编号
        jxbmc: data.teaclaName || undefined, //教学班名称
        fkUserLsId: data.lecturerId || undefined, // 授课老师id
        fkUserLsName: data.lecturerName || undefined, //授课老师名称
        fkKcId: data.courseId || undefined, //课程id
        kcmc: data.courseName || undefined, //课程名称
        ksrq: data.startTime || undefined, //开始时间
        jsrq: data.overTime || undefined, //结束时间
      },
      teachingClassApi.teaCalAdd,
      config
    )
  );
}

/**
 *更新教学班
 * @param {data} 参数
 * {id}  教学班id
 * {teaclaNumber} 教学班编号
 * {teaclaName} 教学班名称
 * {lecturerId}  授课老师id
 * {lecturerName} 授课老师名称
 * {courseId} 课程id
 * {courseName} 课程名称
 * {startTime} 开始时间
 * {overTime} 结束时间
 * @param {config} 配置项
 * @returns
 */
function updateTeaCal(
  data = {
    id: undefined,
    ...PagesData,
  },
  config = {}
) {
  return request(
    submit(
      {
        id: data.id || undefined, //教学班id
        jxbbh: data.teaclaNumber || undefined, //教学班编号
        jxbmc: data.teaclaName || undefined, //教学班名称
        fkUserLsId: data.lecturerId || undefined, // 授课老师id
        fkUserLsName: data.lecturerName || undefined, //授课老师名称
        fkKcId: data.courseId || undefined, //课程id
        kcmc: data.courseName || undefined, //课程名称
        ksrq: data.startTime || undefined, //开始时间
        jsrq: data.overTime || undefined, //结束时间
      },
      teachingClassApi.updateTeaCal,
      config
    )
  );
}

/**
 *批量删除教学班
 * @param {data} 参数 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function delBatchTeaCal(data, config = {}) {
  return request(batchDeletion(data, teachingClassApi.delBatchTeaCal, config));
}

/**
 *根据id查询教学班
 * @param {data} 参数 传入要查询的id
 * @param {config} 配置项
 * @returns
 */
function getTeaClaById(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQueryPath(data, teachingClassApi.getTeaClaById, config)).then(
      ({ result }) => {
        resolve({
          id: result.id || undefined,
          teaclaNumber: result.jxbbh || undefined,
          teaclaName: result.jxbmc || undefined,
          lecturerId: result.fkUserLsId || undefined, // 授课老师id
          lecturerName: result.fkUserLsName || undefined, // 授课老师名称
          courseId: result.fkKcId || undefined,
          courseName: result.kcmc || undefined,
          startTime: result.ksrq || undefined,
          overTime: result.jsrq || undefined,
          orgId:result.jgId || undefined, //机构id
          orgName:result.jgmc || undefined, //机构名称
          schoolId:result.schoolId|| undefined, //学校id
          schoolName:result.school|| undefined, //学校名称
        });
      }
    );
  });
}

/**
 *查询教学班列表
 * @param {data} 参数
 * {teaclaNumber} 教学班编号
 * {teaclaName} 教学班名称
 * {lecturerId}  授课老师id
 * {lecturerName} 授课老师名称
 * {courseId} 课程id
 * {courseName} 课程名称
 * {startTime} 开始时间
 * {overTime} 结束时间
 * @param {config} 配置项
 * @returns
 */
function queryTeaClaList(data = PagesData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          jxbbh: data.teaclaNumber || undefined, //教学班编号
          jxbmc: data.teaclaName || undefined, //教学班名称
          fkUserLsId: data.lecturerId || undefined, // 授课老师id
          fkUserLsName: data.lecturerName || undefined, //授课老师名称
          fkKcId: data.courseId || undefined, //课程id
          kcmc: data.courseName || undefined, //课程名称
          ksrq: data.startTime || undefined, //开始时间
          jsrq: data.overTime || undefined, //结束时间
        },
        teachingClassApi.queryTeaClaList,
        config
      )
    ).then(({ result }) => {
      resolve(
        result.map((item) => ({
          id:item.id || undefined,
          value: item.id || undefined,
          label: item.jxbmc || undefined, //教学班名称
          key:item.id || undefined,
          title:item.jxbmc || undefined, //教学班名称
          lecturerId: item.fkUserLsId || undefined, //授课老师id
          lecturerName: item.fkUserLsName || undefined, //授课老师名称
          courseId: item.fkKcId || undefined, //课程id
          courseName: item.kcmc || undefined, //课程名称
          orgId:item.jgId || undefined, //机构id
          orgName:item.jgmc || undefined, //机构名称
          schoolId:item.schoolId|| undefined, //学校id
          schoolName:item.school|| undefined, //学校名称
          teaclaNumber: item.jxbbh || undefined, //教学班编号
          startTime: item.ksrq || undefined,
          overTime: item.jsrq || undefined,

        }))
      );
    });
  });
}

/**
 *分页查询
 * @param {data} 参数
 * {teaclaNumber} 教学班编号
 * {teaclaName} 教学班名称
 * {lecturerId}  授课老师id
 * {lecturerName} 授课老师名称
 * {courseId} 课程id
 * {courseName} 课程名称
 * {startTime} 开始时间
 * {overTime} 结束时间
 * 除上面参数外 其他参数可自定义
 * @param {config} 配置项
 * @returns
 */
function listPagesTeaCla(data = PagesData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          jxbbh: data.teaclaNumber || undefined, //教学班编号
          jxbmc: data.teaclaName || undefined, //教学班名称
          fkUserLsId: data.lecturerId || undefined, // 授课老师id
          fkUserLsName: data.lecturerName || undefined, //授课老师名称
          fkKcId: data.courseId || undefined, //课程id
          kcmc: data.courseName || undefined, //课程名称
          ksrq: data.startTime || undefined, //开始时间
          jsrq: data.overTime || undefined, //结束时间
          ksrqAndJsrq: data.time || undefined, //起止日期
          ...data,
          ...PagesData,
        },
        teachingClassApi.listPagesTeaCla,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? list.map((item) => ({
                  id: item.id || undefined,
                  teaclaNumber: item.jxbbh || undefined,
                  teaclaName: item.jxbmc || undefined,
                  lecturerId: item.fkKcId || undefined, // 授课老师id
                  lecturerName: item.fkUserLsName || undefined, // 授课老师名称
                  courseId: item.fkKcId || undefined,
                  courseName: item.kcmc || undefined,
                  startTime: item.ksrq || undefined,
                  overTime: item.jsrq || undefined,
                  time: item.ksrqAndJsrq || undefined, //起止日期
                }))
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}
/**
 *将指定行政班下的学生加入教学班中
 * @param {data} 参数
 * {id} 教学班id
 * {ids} 行政班id列表 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function addStudentClaAdmin(data = PagesData, config = {}) {
  return request(
    submit(
      {
        id: data.teaclaId || undefined, // 教学班id
        ids: data.adminclaIds || undefined, //行政班id列表
      },
      teachingClassApi.addStudentClaAdmin,
      config
    )
  );
}
/**
 *将指定学生加入此教学班中
 * @param {data} 参数
 * {id} 教学班id
 * {ids} 学生id列表 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function addStudentTeaCal(data = PagesData, config = {}) {
  return request(
    submit(
      {
        id: data.teaclaId || undefined, // 教学班id
        ids: data.studentsIds || undefined, //学生id列表
      },
      teachingClassApi.addStudentTeaCal,
      config
    )
  );
}
/**
 *删除该教学班下的学生
 * @param {data} 参数
 * {id} 教学班id
 * {ids} 学生id列表 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function deleteTeaCla(data, config = {}) {
  return request(batchDeletion(data, teachingClassApi.deleteTeaCla, config));
}
/**
 *通过教学班id分页查询该教学班已安排的学生列表
 * @param {data} 参数
 * {id} 教学班id
 * 除上面参数外 其他参数可自定义
 * @param {config} 配置项
 * @returns
 */
function getTeaClaStudentList(
  data = { id: undefined, studentParams: PagesData },
  config = {}
) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          id: data.id,
          studentParams: {
            fkJgId: data.orgId || undefined, //机构Id
            fkJgMc: data.orgName || undefined, //机构名称
            fkXszyMc: data.stuproName || undefined, // 学生专业名称
            fkXszyId: data.stuproId || undefined, //学生专业Id
            xm: data.stuName || undefined, //学生姓名
            id: data.stuNumber || undefined, //学号 -暂定
            studentName: data.keyword || undefined, //查询学生
            adminClaName:item.xzbmc|| undefined, //行政班班名称
            ...data,
            ...PagesData,
          },
        },
        teachingClassApi.getTeaClaStudentList,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? list.map((item) => ({
                  id: item.id || undefined,
                  orgId:item.jgId || undefined, //机构id
                  orgName:item.jgmc || undefined, //机构名称
                  schoolId:item.schoolId|| undefined, //学校id
                  schoolName:item.school|| undefined, //学校名称
                  stuproName: item.fkXszyMc || undefined,
                  stuproId: item.fkXszyId || undefined,
                  stuName: item.xm || undefined,
                  stuNumber: item.id || undefined, //暂时写id
                }))
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}
export {
  teaCalAdd,
  updateTeaCal,
  delBatchTeaCal,
  getTeaClaById,
  queryTeaClaList,
  listPagesTeaCla,
  addStudentClaAdmin,
  addStudentTeaCal,
  deleteTeaCla,
  getTeaClaStudentList,
};

==> basic-data-api-1.0.52.tgz: package/src/RequestSettings/tachingClass.js <==
//教学班接口
import {
  submit,
  batchDeletion,
  pagingQuery,
  singleQueryPath,
  postQueryData,
} from "../publicMethod/PublicMethod.js";
import teachingClassApi from "../api/teachingClassApi";
import { request } from "../globalConfiguration";
//教学班接口
const PagesData = {
  teaclaName: undefined,
  teaclaNumber: undefined,
  lecturerId: undefined,
  lecturerName: undefined,
  courseName: undefined,
  courseId: undefined,
  startTime: undefined,
  overTime: undefined,
  time: undefined,
  teaclaId: undefined, //教学Id
  adminclaIds: undefined, // 行政班id列表
  studentsIds: undefined, //学生Id列表
  orgId: undefined, // 机构id
  orgName: undefined, //机构名称
  stuproId: undefined, //学生专业id
  stuproName: undefined, //学生专业名称
  stuName: undefined, //学生姓名
  stuNumber: undefined, //学号
};
/**
 *添加教学班
 * @param {data} 参数
 * {teaclaNumber} 教学班编号
 * {teaclaName} 教学班名称
 * {lecturerId}  授课老师id
 * {lecturerName} 授课老师名称
 * {courseId} 课程id
 * {courseName} 课程名称
 * {startTime} 开始时间
 * {overTime} 结束时间
 * @param {config} 配置项
 * @returns
 */
function teaCalAdd(data = PagesData, config = {}) {
  return request(
    submit(
      {
        jxbbh: data.teaclaNumber || undefined, //教学班编号
        jxbmc: data.teaclaName || undefined, //教学班名称
        fkUserLsId: data.lecturerId || undefined, // 授课老师id
        fkUserLsName: data.lecturerName || undefined, //授课老师名称
        fkKcId: data.courseId || undefined, //课程id
        kcmc: data.courseName || undefined, //课程名称
        ksrq: data.startTime || undefined, //开始时间
        jsrq: data.overTime || undefined, //结束时间
      },
      teachingClassApi.teaCalAdd,
      config
    )
  );
}

/**
 *更新教学班
 * @param {data} 参数
 * {id}  教学班id
 * {teaclaNumber} 教学班编号
 * {teaclaName} 教学班名称
 * {lecturerId}  授课老师id
 * {lecturerName} 授课老师名称
 * {courseId} 课程id
 * {courseName} 课程名称
 * {startTime} 开始时间
 * {overTime} 结束时间
 * @param {config} 配置项
 * @returns
 */
function updateTeaCal(
  data = {
    id: undefined,
    ...PagesData,
  },
  config = {}
) {
  return request(
    submit(
      {
        id: data.id || undefined, //教学班id
        jxbbh: data.teaclaNumber || undefined, //教学班编号
        jxbmc: data.teaclaName || undefined, //教学班名称
        fkUserLsId: data.lecturerId || undefined, // 授课老师id
        fkUserLsName: data.lecturerName || undefined, //授课老师名称
        fkKcId: data.courseId || undefined, //课程id
        kcmc: data.courseName || undefined, //课程名称
        ksrq: data.startTime || undefined, //开始时间
        jsrq: data.overTime || undefined, //结束时间
      },
      teachingClassApi.updateTeaCal,
      config
    )
  );
}

/**
 *批量删除教学班
 * @param {data} 参数 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function delBatchTeaCal(data, config = {}) {
  return request(batchDeletion(data, teachingClassApi.delBatchTeaCal, config));
}

/**
 *根据id查询教学班
 * @param {data} 参数 传入要查询的id
 * @param {config} 配置项
 * @returns
 */
function getTeaClaById(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQueryPath(data, teachingClassApi.getTeaClaById, config)).then(
      ({ result }) => {
        resolve({
          id: result.id || undefined,
          teaclaNumber: result.jxbbh || undefined,
          teaclaName: result.jxbmc || undefined,
          lecturerId: result.fkUserLsId || undefined, // 授课老师id
          lecturerName: result.fkUserLsName || undefined, // 授课老师名称
          courseId: result.fkKcId || undefined,
          courseName: result.kcmc || undefined,
          startTime: result.ksrq || undefined,
          overTime: result.jsrq || undefined,
          orgId:result.jgId || undefined, //机构id
          orgName:result.jgmc || undefined, //机构名称
          schoolId:result.schoolId|| undefined, //学校id
          schoolName:result.school|| undefined, //学校名称
        });
      }
    );
  });
}

/**
 *查询教学班列表
 * @param {data} 参数
 * {teaclaNumber} 教学班编号
 * {teaclaName} 教学班名称
 * {lecturerId}  授课老师id
 * {lecturerName} 授课老师名称
 * {courseId} 课程id
 * {courseName} 课程名称
 * {startTime} 开始时间
 * {overTime} 结束时间
 * @param {config} 配置项
 * @returns
 */
function queryTeaClaList(data = PagesData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          jxbbh: data.teaclaNumber || undefined, //教学班编号
          jxbmc: data.teaclaName || undefined, //教学班名称
          fkUserLsId: data.lecturerId || undefined, // 授课老师id
          fkUserLsName: data.lecturerName || undefined, //授课老师名称
          fkKcId: data.courseId || undefined, //课程id
          kcmc: data.courseName || undefined, //课程名称
          ksrq: data.startTime || undefined, //开始时间
          jsrq: data.overTime || undefined, //结束时间
        },
        teachingClassApi.queryTeaClaList,
        config
      )
    ).then(({ result }) => {
      resolve(
        result.map((item) => ({
          id:item.id || undefined,
          value: item.id || undefined,
          label: item.jxbmc || undefined, //教学班名称
          key:item.id || undefined,
          title:item.jxbmc || undefined, //教学班名称
          lecturerId: item.fkUserLsId || undefined, //授课老师id
          lecturerName: item.fkUserLsName || undefined, //授课老师名称
          courseId: item.fkKcId || undefined, //课程id
          courseName: item.kcmc || undefined, //课程名称
          orgId:item.jgId || undefined, //机构id
          orgName:item.jgmc || undefined, //机构名称
          schoolId:item.schoolId|| undefined, //学校id
          schoolName:item.school|| undefined, //学校名称
          teaclaNumber: item.jxbbh || undefined, //教学班编号
          startTime: item.ksrq || undefined,
          overTime: item.jsrq || undefined,

        }))
      );
    });
  });
}

/**
 *分页查询
 * @param {data} 参数
 * {teaclaNumber} 教学班编号
 * {teaclaName} 教学班名称
 * {lecturerId}  授课老师id
 * {lecturerName} 授课老师名称
 * {courseId} 课程id
 * {courseName} 课程名称
 * {startTime} 开始时间
 * {overTime} 结束时间
 * 除上面参数外 其他参数可自定义
 * @param {config} 配置项
 * @returns
 */
function listPagesTeaCla(data = PagesData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          jxbbh: data.teaclaNumber || undefined, //教学班编号
          jxbmc: data.teaclaName || undefined, //教学班名称
          fkUserLsId: data.lecturerId || undefined, // 授课老师id
          fkUserLsName: data.lecturerName || undefined, //授课老师名称
          fkKcId: data.courseId || undefined, //课程id
          kcmc: data.courseName || undefined, //课程名称
          ksrq: data.startTime || undefined, //开始时间
          jsrq: data.overTime || undefined, //结束时间
          ksrqAndJsrq: data.time || undefined, //起止日期
          ...data,
          ...PagesData,
        },
        teachingClassApi.listPagesTeaCla,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? list.map((item) => ({
                  id: item.id || undefined,
                  teaclaNumber: item.jxbbh || undefined,
                  teaclaName: item.jxbmc || undefined,
                  lecturerId: item.fkKcId || undefined, // 授课老师id
                  lecturerName: item.fkUserLsName || undefined, // 授课老师名称
                  courseId: item.fkKcId || undefined,
                  courseName: item.kcmc || undefined,
                  startTime: item.ksrq || undefined,
                  overTime: item.jsrq || undefined,
                  time: item.ksrqAndJsrq || undefined, //起止日期
                }))
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}
/**
 *将指定行政班下的学生加入教学班中
 * @param {data} 参数
 * {id} 教学班id
 * {ids} 行政班id列表 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function addStudentClaAdmin(data = PagesData, config = {}) {
  return request(
    submit(
      {
        id: data.teaclaId || undefined, // 教学班id
        ids: data.adminclaIds || undefined, //行政班id列表
      },
      teachingClassApi.addStudentClaAdmin,
      config
    )
  );
}
/**
 *将指定学生加入此教学班中
 * @param {data} 参数
 * {id} 教学班id
 * {ids} 学生id列表 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function addStudentTeaCal(data = PagesData, config = {}) {
  return request(
    submit(
      {
        id: data.teaclaId || undefined, // 教学班id
        ids: data.studentsIds || undefined, //学生id列表
      },
      teachingClassApi.addStudentTeaCal,
      config
    )
  );
}
/**
 *删除该教学班下的学生
 * @param {data} 参数
 * {id} 教学班id
 * {ids} 学生id列表 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function deleteTeaCla(data, config = {}) {
  return request(batchDeletion(data, teachingClassApi.deleteTeaCla, config));
}
/**
 *通过教学班id分页查询该教学班已安排的学生列表
 * @param {data} 参数
 * {id} 教学班id
 * 除上面参数外 其他参数可自定义
 * @param {config} 配置项
 * @returns
 */
function getTeaClaStudentList(
  data = { id: undefined, studentParams: PagesData },
  config = {}
) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          id: data.id,
          studentParams: {
            fkJgId: data.orgId || undefined, //机构Id
            fkJgMc: data.orgName || undefined, //机构名称
            fkXszyMc: data.stuproName || undefined, // 学生专业名称
            fkXszyId: data.stuproId || undefined, //学生专业Id
            xm: data.stuName || undefined, //学生姓名
            id: data.stuNumber || undefined, //学号 -暂定
            studentName: data.keyword || undefined, //查询学生
            adminClaName:data.xzbmc|| undefined, //行政班班名称
            ...data,
            ...PagesData,
          },
        },
        teachingClassApi.getTeaClaStudentList,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? list.map((item) => ({
                  id: item.id || undefined,
                  orgId:item.jgId || undefined, //机构id
                  orgName:item.jgmc || undefined, //机构名称
                  schoolId:item.schoolId|| undefined, //学校id
                  schoolName:item.school|| undefined, //学校名称
                  stuproName: item.fkXszyMc || undefined,
                  stuproId: item.fkXszyId || undefined,
                  stuName: item.xm || undefined,
                  stuNumber: item.id || undefined, //暂时写id
                }))
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}
export {
  teaCalAdd,
  updateTeaCal,
  delBatchTeaCal,
  getTeaClaById,
  queryTeaClaList,
  listPagesTeaCla,
  addStudentClaAdmin,
  addStudentTeaCal,
  deleteTeaCla,
  getTeaClaStudentList,
};
